@@ -1,5 +1,5 @@
 use log::{info, warn};
-use rocket::http::CookieJar;
+use rocket::http::{Cookie, CookieJar};
 use rocket::response::Redirect;
 use rocket::State;
 use rocket_dyn_templates::Template;
@@ -20,9 +20,17 @@ async fn index(
         Some(user_json) => {
             let user: User = serde_json::from_str(user_json.value())?;
             let config = PrintNannyConfig::new(config_file.0.as_deref())?;
-            assert_eq!(config.user, Some(user));
-            info!("Attaching context to view {:?}", &config);
-            Ok(Response::Template(Template::render("index", config)))
+
+            // if config + cookie mismatch, nuke cookie (profile switch in developer mode)
+            if config.user != Some(user.clone()) {
+                warn!("config.user {:?} did not match COOKIE_USER {:?}, deleting cookie to force re-auth", config.user, &user);
+                jar.remove_private(Cookie::named(auth::COOKIE_USER));
+                Ok(Response::Redirect(Redirect::to("/login")))
+            } else {
+                info!("Auth success! COOKIE_USER matches config.user");
+                info!("Attaching context to view {:?}", &config);
+                Ok(Response::Template(Template::render("index", config)))
+            }
         }
         None => {
             warn!(
